@@ -180,7 +180,7 @@
 #define HAVE_SYSEXITS_H 1
 
 /* Define if building libLLVM shared library */
-/* #undef LLVM_BUILD_LLVM_DYLIB */
+#define LLVM_BUILD_LLVM_DYLIB
 
 /* Define if building LLVM with BUILD_SHARED_LIBS */
 /* #undef LLVM_BUILD_SHARED_LIBS */
@@ -196,7 +196,7 @@
 #define LLVM_ENABLE_DIA_SDK 0
 
 /* Define if plugins enabled */
-/* #undef LLVM_ENABLE_PLUGINS */
+#define LLVM_ENABLE_PLUGINS
 
 /* Define if logf128 is available */
 /* #undef LLVM_HAS_LOGF128 */
